/**********************************************************************
 ***                                                                ***
 ***              Random Number Generator Function                  ***
 ***                                                                ***
 ***                    By:  Paul A. Balyoz                         ***
 ***                    Modified:  07/09/92                         ***
 ***                    File:  rnd.c                                ***
 ***                                                                ***
 *** Copyright (C) 1987 by Paul A. Balyoz, all rights reserved      ***
 *** This program may not be sold in any form or used as an entice- ***
 *** ment for sale without written permission from the author.      ***
 ***                                                                ***
 **********************************************************************/


/*
 *                      RND Function Information
 *                      ========================
 *
 *  Note below:  'max' = 32767, 'min' = -32768.  (16-bit signed int)
 *----------------------------------------------------------------------
 * rnd (value)      Random Number Generator and Seeder
 * int value;
 *
 *  If "value" is	Then rnd() will
 *  -------------	---------------
 *      1..max    	generate a random number between 0 and value-1,
 *      0         	reseeds the random number generator internally,
 *     -1..min   	reseeds the random number generator with the
 *              	absolute-value of "value".
 *
 *      Rnd returns an integer within the range 0 to value-1, where
 * value is the argument.  If value = 0 then the random number is re-
 * seeded with the seconds since 1970 and 0 is returned.  If value < 0
 * then the random number is reseeded with -(value + 1).  The latter is
 * useful in generating a specific pseudo-random sequence repetitively.
 *      Remember to seed the generator AT LEAST ONCE before using it,
 * or your program will always use the same series of numbers.
 *----------------------------------------------------------------------
 */


/**********************************************************************
 ***                                rnd                             ***
 **********************************************************************/

#include <sys/types.h>

int rnd (value)         /* random number generator and seeder */
int value;              /* upper range for random number */
{
    extern long time ();        /* returns time in seconds */
    extern int  rand ();        /* returns int, 0 -> max-1  */
    extern int  srand ();       /* takes seed, 0 -> max-1   */

/* if value is 1 -> max-1, return a random int between 0 and value-1 */

    if (value > 0)
    {
	return ((int) ((long)(rand() & 0x7FFF) * value / 0x8000L));
    }

/*
 *  Re-seed the random number generator with current time in seconds
 *  plus the process ID number.  Good for most any purpose.
 */

    else if (value == 0)
    {
	srand ((unsigned) (time((long *)0) + getpid()));
    }

/*
 *  Re-seed the random number generator with the value passed in
 */

    else
    {
	srand ((unsigned) (-(value + 1)));
    }

/*
 *  All finished.
 */

    return (0);
}
