#
# subdom.awk - parse AXFR records from DIG, look only at the NS records,
#             and print only the sub-domain names.
# NOTICE: We know that input has been completely lower-cased.  ("tr A-Z a-z")
#

BEGIN {
	CONTINUATION = 0;
}

# Skip all lines inside this continuation, watching for the close-parenthesis.

CONTINUATION==1 {
	if ($0 ~ /\)/)
		CONTINUATION = 0;
	next;
}

# If open-parenthesis on this line, remember it but parse this line anyway.

/\(/ {
	CONTINUATION = 1;
}

# If line is all comment, skip it.

/^;/ {
	next;
}

NF >= 4 && CONTINUATION==0 {

# NS and SOA records: print the first field because it's the subdomain name.

	if ($3~/^ns$/ || $3~/^soa$/) {
		print $1 " subdomain";

# other records: print the sub-domain name portion of the first field.

	} else {
		len = split ($1, f, ".");
		for (i=2; i<len; i++)
			printf ("%s.", f[i]);
		printf ("%s\n", f[len]);
	}
	next;
}
