#
# subzone.awk - parse AXFR records from DIG, look only at the NS records,
#     		and print only the sub-zone names.
#		Output includes multiple copies of each zone, one for each NS
#		record found.
#

BEGIN {
	zonename = "------------------------------------------";  # illegal
	CONTINUATION = 0;
}


# If line is all comment or all empty, skip it.

/^;/ || /^$/ {
	next;
}


# Skip all lines inside this continuation, watching for the close-parenthesis.

CONTINUATION==1 {
	if ($0 ~ /\)/)
		CONTINUATION = 0;
	next;
}


# Handle normal records, and the first line of continuation records.

NF >= 4 && CONTINUATION == 0 {

# SOA records: just remember the zone name

	if ($3 == "SOA") {
		zonename = $1;

# NS records: if it is a subzone, print its name.

	} else if ($3 == "NS") {
		# ALERT Should be case-insensitive comparison here, but its not!
		if (length($1) > length(zonename) && \
substr($1,length($1)-length(zonename)+1,length(zonename)) == zonename) {
			print $1;
		}
	}
}


# If open-parenthesis on this line, more stuff is coming on following lines.

/\(/ {
	CONTINUATION = 1;
}
